/**********************************************************************
 *
 * userdb.cpp -- functions to handle a language macro database
 * Copyright (C) 1999  DigiLib Systems Limited, New Zealand
 *
 * A component of the Greenstone digital library software
 * from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *********************************************************************/

#include "gsdlconf.h"
#include "langdb.h"
#include "gsdltimes.h"
#include "fileutil.h"
#include <stdlib.h>


////////////////
// macroinfo_t
////////////////

void macroinfo_t::clear () {
  macroname.clear();
  macrotext.clear();
}

macroinfo_t &macroinfo_t::operator=(const macroinfo_t &x) {
  macroname = x.macroname;
  macrotext = x.macrotext;
  
  return *this;
}


// functions dealing with language macro databases

// returns true on success (in which case macroinfo will contain
// the information for this macro)
bool get_macro_info (gdbmclass &langdb, const text_t &macroname,
		    macroinfo_t &macroinfo) {
  macroinfo.clear();
  
  infodbclass info;
  if (langdb.getinfo (macroname, info)) {
    macroinfo.macroname = info["macroname"];
    macroinfo.macrotext = info["macrotext"];
    return true;
  }

  return false;
}

bool get_macro_info (const text_t &langdbfile, const text_t &macroname, 
		     macroinfo_t &macroinfo) {
  // THIS IS GOING TO READ FROM THE MACRO FILE FIRST TIME...

  gdbmclass langdb;
  if (!langdb.opendatabase(langdbfile, GDBM_READER, 1000, true)) {
/*    if (!langdbfile.empty() && !file_exists (langdbfile) &&
	macroname == "admin") {*/
    if (!langdbfile.empty()) {
      // no database -- create a database with an initial account
      macroinfo.clear();
      macroinfo.macroname = "language";
      macroinfo.macrotext = "language"; // this needs to be extracted from langdbfile
      return set_macro_info (langdbfile, macroname, macroinfo);
    }
    return false;
  }

  bool success = get_macro_info (langdb, macroname, macroinfo);
  langdb.closedatabase();

  return success;
}

// returns true on success
bool set_macro_info (gdbmclass &langdb, const text_t &macroname,
		    const macroinfo_t &macroinfo) {
  infodbclass info;
  info["macroname"] = macroinfo.macroname;
  info["macrotext"] = macroinfo.macrotext;

  return langdb.setinfo (macroname, info);
}

bool set_macro_info (const text_t &langdbfile, const text_t &macroname,
		    const macroinfo_t &macroinfo) {
  gdbmclass langdb;
  if (!langdb.opendatabase(langdbfile, GDBM_WRCREAT, 1000, true)) return false;
  
  bool success = set_macro_info (langdb, macroname, macroinfo);
  langdb.closedatabase();
  
  return success;
}
